pub fn catalog_at_worktree(repo_path: &Path) -> Result<OntologyCatalog>Expand description
Build catalog from ontology files in the working tree: git-indexed paths plus untracked workspace files (respecting path jail and scan limits).
pub fn catalog_at_worktree(repo_path: &Path) -> Result<OntologyCatalog>Build catalog from ontology files in the working tree: git-indexed paths plus untracked workspace files (respecting path jail and scan limits).